#
# spec file for package mcabber
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mcabber
Version:        1.1.0
Release:        bp153.1.16
Summary:        Modular XMPP client on ncurses
License:        GPL-2.0+
Group:          Productivity/Networking/Instant Messenger
Url:            https://mcabber.com/
Source:         https://mcabber.com/files/%{name}-%{version}.tar.bz2
Source1:        https://mcabber.com/files/%{name}-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
# PATCH-FEATURE-OPENSUSE up_one_line_message_length.patch
Patch0:         up_one_line_message_length.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  libgpgme-devel
BuildRequires:  libotr-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(enchant)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(loudmouth-1.0)

%description
mcabber is a small XMPP console client on ncurses. It features
SSL support, history logging, external actions, OTR support,
conferences (MUC) support.

%package devel
Summary:        Headers for modular XMPP client on ncurses
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       pkgconfig(glib-2.0)
Requires:       pkgconfig(gmodule-2.0)
Requires:       pkgconfig(loudmouth-1.0)

%description devel
mcabber is a small XMPP console client on ncurses. It features
SSL support, history logging, external actions, OTR support,
conferences (MUC) support.

%prep
%setup -q
%patch0
mv -f %{name}rc.example %{name}rc

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-enchant \
  --enable-hgcset \
  --enable-otr
make %{?_smp_mflags} V=1

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}%{_datadir}

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING NEWS README TODO
%doc %{name}rc doc/%{name}.?.* doc/manpage.css
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_mandir}/man?/%{name}.?%{?ext_man}

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Thu May  3 2018 bjorn.lie@gmail.com
- Replace enchant-devel with pkgconfig(enchant) BuildRequires.
* Wed Aug  9 2017 pgajdos@suse.com
- update to 1.1.0:
  * New "VI" mode (option 'vi_mode') (Holger Weiß)
  * Fix issues in buddylist rebuild (franky)
  * Do not use g_slist_free_full() which requires glib2 2.28.0 (Frank Bergmann)
  * Use UTF-8 validation of file content when sending a message from a file
  * Documentation updates
- use enchant instead of aspell [bsc#1052959]
* Fri Feb 10 2017 sor.alexei@meowr.ru
- Update to version 1.0.5:
  * Much better performances with huge rosters.
  * Fix an issue with carbons (CVE-2017-5589, bsc#1024690).
  * Fix a small memory leak.
  * contrib/vim: Support reloading filetype detection.
* Sat Dec 10 2016 sor.alexei@meowr.ru
- Update to version 1.0.4 (changes since 1.0.2):
  * Link with the tinfo library.
  * Fix default modules directory on OpenBSD.
  * Create the history log directory if it doesn't exist.
  * [OTR] Do not send empty subjects.
  * [UI] /set does not display password values anymore.
  * [MUC] Use nick to set the role.
  * Check the origin of roster pushes (bsc#1014976).
    See Gajim's CVE-2015-8688 and
    https://gultsch.de/gajim_roster_push_and_message_interception.html
  * Misc help/documentation updates.
* Fri Mar  4 2016 sor.alexei@meowr.ru
- Update to 1.0.2:
  * Compatible with Loudmouth >=1.5.3 with SHA256 support.
  * Ignore the untrusted certificate warning when user sets a
    fingerprint.
  * Stop HTML-escaping OTR messages – only strip known tags.
  * Read $HOME/.mcabberrc if there is no mcabber configuration
    directory.
  * Minor documentation updates.
* Thu Feb 11 2016 sor.alexei@meowr.ru
- Update to 1.0.1:
  * [PGP] Improve PGP-encryption support.
  * [PGP] Improve support for GnuPG v2+.
  * [PGP] Encrypt messages with our own PGP key and decrypt our own
    encrypted messages when Carbons are enabled.
  * [PGP] New PGP options: 'gpg_path' and 'gpg_home'.
  * [PGP] Check all signatures and stop immediately if one could be
    verified.
  * Improve Carbons support.
  * New option: 'clear_unread_on_carbon'.
  * Improve SSL fingerprint management;
    Display the server SSL fingerprint when we connect.
  * Use XDG configuration directory if it contains a configuration
    file.
  * Fix a few memory leaks.
  * Fix external password support (especially on OS X).
  * Fix resizing when mcabber is built with --enable-sigwinch.
  * Fix reading of history log files w/o LF character.
  * Minor documentation updates.
  * Other misc. bugfixes and cleanups.
- Use tarball signing.
* Thu Aug 20 2015 sor.alexei@meowr.ru
- Correct ncurses BuildRequires.
* Sun Jun 28 2015 sor.alexei@meowr.ru
- Update to 1.0.0:
  * Message Carbons support / XEP-0280.
  * Support for using external password managers.
  * [UI] Add a backward completion.
  * [UI] Multilanguage spell checking.
  * [UI] New option 'buffer_smart_scrolling' to lock buffer.
    automatically when scrolled u.
  * [UI] New command /roster next_open_buffer.
  * [UI] New option 'attention_char'.
  * [UI] Try to display the GLib warnings in the log window.
  * [UI] Display the number of occupants in MUC rooms.
  * [UI] New option switch /room topic -u to unescape the topic.
  * [MUC] A Support for storing MUC room passwords.
  * [MUC] Use bookmarked password (if any) when using "/room join".
  * [Hooks] New "hook-mdr-received" hook.
  * Remove support for obsolete XEP 22.
  * Misc. bugfixes and minor improvements.
* Fri Mar  6 2015 egdfree@opensuse.org
- add patch up_one_line_message_length.patch (bnc#906685)
* Thu Oct 30 2014 sor.alexei@meowr.ru
- Update to 0.10.3:
  * [UI] Add option 'iq_time_hide'.
  * [UI] Add 'iq_version_hide_os', 'iq_version_hide_version'.
  * Improved handling of damaged history log files.
  * Switch to libotr v4 API.
  * Add SSL options.
    These options require a patched Loudmouth library.
  - "ssl_ciphers" to define the allowed ciphers.
  - "ssl_ca" to set additional trusted certificates.
  * Fix compilation for old loudmouth libraries.
  * Add 'color_timestamp' to highlight timestamp added by server.
  * Handle SIGHUP signal.
  * Misc. bugfixes.
- Drop mcabber.desktop.
- Major spec cleanup.
* Sun Jun 16 2013 dap@open.by
- libotr2-devel became required to build to fix oS 12.3+.
- Fixed up via `spec-cleaner`.
- License tag was set to GPL-2.0+ to fix warning.
* Sun Dec  2 2012 pascal.bleser@opensuse.org
- update to 0.10.2:
  * the FIFO and url_regex systems have been modularized
  * load the appropriate modules if you want these features
  (the sample configuration file has been updated)
* Wed Dec  1 2010 pascal.bleser@opensuse.org
- update to 0.10.1:
  * display a warning when the configuration file hasn't been updated
  * display better messages when connecting to the XMPP server
  * [MUC] do not block MUC private messages when 'block_unsubscribed' is set
  * [MUC] fix handling of empty room topic
  * [MUC] add caps to presence when joining a MUC room
  * new option 'completion_ignore_case' - completion is now case sensitive by default
  * display module API information in the output of /version
  * increase the number of available categories for completions
  * [Hooks] new "hook-subscription" hook, update to the message-in hooks (See ChangeLog.api)
  * many misc. bugfixes
  * minor documentation update
* Sun Apr 11 2010 pascal.bleser@opensuse.org
- update to 0.10.0:
  * switch to the loudmouth Jabber library
  * "username" has been replaced with "jid" in the configuration file
  * mcabber can now do DNS SRV lookups
  * buffers have priorities, that are used to jump to the next unread buffer
  * the attention sign (!) is displayed for urgent messages or when the user nickname is used in a MUC room
  * prints a list of options with "/set"
  * add support for modules
  * sample "beep" module
  * message receipts (XEP-0184) support
  * new command /request ping
  * add libidn support
  * allow changing the nickname in MUC bookmarks
  * a suffix can be appended to completed nicknames
  * command "/source" now accepts a file pattern
  * tracelog level can now be changed at runtime
  * small vCard support improvements
  * startup status can be set in the configuration file
  * obsolete option 'hide_offline_buddies' has been removed
  * obsolete XEP-0022 (message events) is now disabled by default
  * no suffix is displayed in the status bar after the 'info' value
  * add vim syntax file for mcabber history log files
* Wed Oct  7 2009 pascal.bleser@opensuse.org
- update to 0.9.10:
  * supports spell checking with Enchant
  * many small improvements and bugfixes
* Thu Oct  9 2008 guru@unixtech.be
- update to 0.9.9:
  * a few bugfixes
  * some translation updates
  * a new Czech translation
* Mon Oct  6 2008 guru@unixtech.be
- update to 0.9.8:
  * URLs can be extracted from messages to the log window using the url_regex
    option
  * OTR messages are now flagged with "O"
  * two new commands have been added, "/buffer save" and "/echo"
  * several new options and UI improvements
* Thu Apr 17 2008 guru@unixtech.be
- new upstream version
* Sun Jan 13 2008 guru@unixtech.be
- update to 0.9.6
* Wed Nov 21 2007 guru@unixtech.be
- update to 0.9.5
* Sun Oct 28 2007 guru@unixtech.be
- enabled aspell support
- use gnutls instead of openssl
- added OTR support (requires libotr >= 0.3.1)
- update to 0.9.4
* Wed Jun 20 2007 guru@unixtech.be
- update to 0.9.3
* Wed Jun 13 2007 guru@unixtech.be
- initial openSUSE Build Service submission
